@@ -1,3 +1,4 @@
+import os
 import pathlib
 import json
 import yaml
@@ -8,30 +9,51 @@ from math import log10, floor
 import ipywidgets as w
 from IPython.display import display, Markdown
 import codecs
-from pydantic import BaseModel, validator, Field
+from pydantic import BaseModel, field_validator, Field, ValidationInfo
 import typing as ty
 import importlib.util
 import inspect
 import immutables
 import getpass
+import logging
 
+
+logger = logging.getLogger(__name__)
 frozenmap = immutables.Map
 
-
-def make_new_path(path, *args, **kwargs):
-    return path
-
-
 try:
-    # TODO: remove these.
-    from mf_file_utilities import go as open_file
-    from mf_file_utilities.applauncher_wrapper import make_new_path
+    import maplocal
+
+    if maplocal.maplocal_openlocal_exists():
+        from maplocal import openlocal as open_path
+        from maplocal import maplocal as make_new_path
+    else:
+
+        def make_new_path(path, *args, **kwargs):
+            return path
+
+        def open_path(path):
+            import subprocess
+            import sys
+
+            if sys.platform == "linux":
+                subprocess.call(["xdg-open", path])
+            else:
+                subprocess.call(["explorer.exe", path])
+
 except:
 
-    def open_file(path):
-        import subprocess
+    def make_new_path(path, *args, **kwargs):
+        return path
 
-        subprocess.call(["open", path])
+    def open_path(path):
+        import subprocess
+        import sys
+
+        if sys.platform == "linux":
+            subprocess.call(["xdg-open", path])
+        else:
+            subprocess.call(["explorer.exe", path])
 
 
 def getuser():
@@ -44,7 +66,8 @@ def getuser():
 # ------------------------------
 def str_presenter(dumper, data):
     """configures yaml for dumping multiline strings
-    Ref: https://stackoverflow.com/questions/8640959/how-can-i-control-what-scalar-form-pyyaml-uses-for-my-data"""
+    Ref: https://stackoverflow.com/questions/8640959/how-can-i-control-what-scalar-form-pyyaml-uses-for-my-data
+    """
     if len(data.splitlines()) > 1:  # check for multiline string
         return dumper.represent_scalar("tag:yaml.org,2002:str", data, style="|")
     return dumper.represent_scalar("tag:yaml.org,2002:str", data)
@@ -214,13 +237,14 @@ def read_yaml(fpth, encoding="utf8"):
     read yaml file.
 
     Ref:
-        https://stackoverflow.com/questions/1773805/how-can-i-parse-a-yaml-file-in-python"""
+        https://stackoverflow.com/questions/1773805/how-can-i-parse-a-yaml-file-in-python
+    """
     with open(fpth, encoding=encoding) as stream:
         try:
             data = yaml.safe_load(stream)
+            return data
         except yaml.YAMLError as exc:
             print(exc)
-    return data
 
 
 def file(self: Type[BaseModel], path: pathlib.Path, **json_kwargs):
@@ -257,49 +281,26 @@ class PyObj(BaseModel):
         None, description="ignore, this is overwritten by a validator"
     )
 
-    @validator("module_name", always=True)
-    def _module_name(cls, v, values):
-        return values["path"].stem
+    @field_validator("module_name")
+    @classmethod
+    def _module_name(cls, v, info: ValidationInfo):
+        return info.data["path"].stem
 
 
 def load_PyObj(obj: PyObj):
-    spec = importlib.util.spec_from_file_location(obj.module_name, obj.path)
+    submodule_search_locations = None
+    p = obj.path
+    if obj.path.is_dir():
+        p = p / "__main__.py"
+        submodule_search_locations = []
+    spec = importlib.util.spec_from_file_location(
+        obj.module_name, p, submodule_search_locations=submodule_search_locations
+    )
     foo = importlib.util.module_from_spec(spec)
     spec.loader.exec_module(foo)
     return getattr(foo, obj.obj_name)
 
 
-def create_pydantic_json_file(pyobj: PyObj, path: pathlib.Path, **kwargs):
-    """
-    loads a pyobj (which must be a pydantic model) and then saves the default Json to file.
-    this requires defaults for all pydantic attributes.
-
-    Todo:
-        could extend the functionality to cover models that don't have defaults
-        using [pydantic-factories](https://github.com/Goldziher/pydantic-factories)
-
-    Args:
-        pyobj (PyObj): definition of where to get a pydantic model
-        path (pathlib.Path): where to save the pydantic json
-        **kwargs : passed to the pydantic model upon initiation
-
-    Returns:
-        path
-    """
-    obj = load_PyObj(pyobj)
-    assert (
-        str(type(obj)) == "<class 'pydantic.main.ModelMetaclass'>"
-    ), "the python object must be a pydantic model"
-    if not hasattr(obj, "file"):
-        setattr(obj, "file", file)
-    assert hasattr(
-        obj, "file"
-    ), "the pydantic BaseModel must be extended to have method 'file' for writing model to json"
-    myobj = obj(**kwargs)
-    myobj.file(path)
-    return path
-
-
 # TODO: use obj_to_importstr and obj_from_importstr rather than load_PyObj
 def obj_to_importstr(obj: ty.Callable):  # NOT IN USE
     """
@@ -354,72 +355,25 @@ def obj_from_importstr(importstr: str) -> ty.Type:
     return getattr(importlib.import_module(mod), nm)
 
 
-class SerializableCallable(BaseModel):  # NOT IN USE
-    callable_str: ty.Union[ty.Callable, str] = Field(
-        ...,
-        description="import string that can use importlib\
-                                                              to create a python obj. Note. if a Callable object\
-                                                              is given it will be converted into a string",
-    )
-    callable_obj: ty.Union[ty.Callable, ty.Type] = Field(None, exclude=True)
-
-    @validator("callable_str", always=True)
-    def _callable_str(cls, v, values):
-        if type(v) != str:
-            return obj_to_importstr(v)
-        invalid = [i for i in "!@#£[]()<>|¬$%^&*,?''- "]
-        for i in invalid:
-            if i in v:
-                raise ValueError(
-                    f"callable_str = {v}. import_str must not contain spaces {i}"
-                )
-        return v
-
-    @validator("callable_obj", always=True)
-    def _callable_obj(cls, v, values):
-        return obj_from_importstr(values["callable_str"])
+def argspecs_in_kwargs(call: ty.Callable, kwargs: dict):
+    """get argspecs for kwargs"""
+    return {k: v for k, v in kwargs.items() if k in inspect.getfullargspec(call).args}
 
 
-def create_pydantic_json_file(
-    pyobj: ty.Union[str, PyObj], path: pathlib.Path, **kwargs
-):
-    """
-    loads a pyobj (which must be a pydantic model) and then saves the default Json to file.
-    this requires defaults for all pydantic attributes.
-
-    Todo:
-        could extend the functionality to cover models that don't have defaults
-        using [pydantic-factories](https://github.com/Goldziher/pydantic-factories)
-
-    Args:
-        pyobj (SerializableCallable): definition of where to get a pydantic model
-        path (pathlib.Path): where to save the pydantic json
-        **kwargs : passed to the pydantic model upon initiation
-
-    Returns:
-        path
-    """
-    if type(pyobj) == str:
-        obj = SerializableCallable(pyobj).callable_obj
+def traits_in_kwargs(call: ty.Callable, kwargs: dict):
+    """get traits for kwargs"""
+    if not hasattr(call, "traits"):
+        logger.info(f"{call.__name__} does not have traits attribute")
+        return {}
     else:
-        obj = load_PyObj(pyobj)
-    assert (
-        str(type(obj)) == "<class 'pydantic.main.ModelMetaclass'>"
-    ), "the python object must be a pydantic model"
-    if not hasattr(obj, "file"):
-        setattr(obj, "file", file)
-    assert hasattr(
-        obj, "file"
-    ), "the pydantic BaseModel must be extended to have method 'file' for writing model to json"
-    myobj = obj(**kwargs)
-    myobj.file(path)
-    return path
+        return {k: v for k, v in kwargs.items() if k in list(call.traits(call).keys())}
 
 
 def remove_non_present_kwargs(callable_: ty.Callable, di: dict):
     """do this if required (get allowed args from callable)"""
-    args = inspect.getfullargspec(callable_).args
-    return {k_: v_ for k_, v_ in di.items() if k_ in args}
+    argspec = argspecs_in_kwargs(callable_, di)
+    traits = traits_in_kwargs(callable_, di)
+    return {**argspec, **traits}
 
 
 def get_ext(fpth):
@@ -430,6 +384,8 @@ def get_ext(fpth):
 def st_mtime_string(path):
     """st_mtime_string for a given path"""
     try:
+        import time
+
         t = path.stat().st_mtime
         return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(t))
     except:
@@ -442,3 +398,68 @@ def check_installed(package_name):
         return False
     else:
         return True
+
+
+def html_link(url: str, description: str, color: str = "blue"):
+    """returns an html link string to open in new tab
+
+    Args:
+        url (url):
+        description (str): the text to display for the link
+        color (str, optional): color of description text. Defaults to "blue".
+
+    Returns:
+        str: html text
+    """
+    return f'<font color="{color}"><a href="{url}" target="blank" >{description}</a></font>'
+
+
+def get_user():
+    """get user. gets JUPYTERHUB_USER if present (i.e. if notebook served via a JupyterHub)"""
+    nm = "JUPYTERHUB_USER"
+    if nm in list(os.environ.keys()):
+        return os.environ[nm]
+    else:
+        from getpass import getuser
+
+        return getuser()
+
+def type_as_json(value):
+    if isinstance(value, str):
+        return "string"
+    elif isinstance(value, int):
+        return "integer"
+    elif isinstance(value, float):
+        return "number"
+    elif isinstance(value, bool):
+        return "number"
+    elif isinstance(value, list):
+        return "array"
+    elif isinstance(value, dict):
+        return "object" + "-" + "".join(value.keys())
+    elif isinstance(value, None):
+        return "null"
+    else:
+        raise ValueError(
+            "value must be: string, integer, number, array, object or None"
+        )
+
+def json_as_type(s)->ty.Type:
+    if s == "string":
+        return str
+    elif s == "integer":
+        return int
+    elif s == "number":
+        return float
+    elif s == "boolean":
+        return bool
+    elif s == "array":
+        return list
+    elif s == "object":
+        return dict
+    elif s == "null":
+        return None
+    else:
+        raise ValueError(
+            "value must be: string, integer, number, array, object or None"
+        )
\ No newline at end of file
