@@ -2,18 +2,20 @@
 # ---
 # jupyter:
 #   jupytext:
-#     formats: py:light
+#     custom_cell_magics: kql
+#     formats: py:percent
 #     text_representation:
 #       extension: .py
-#       format_name: light
-#       format_version: '1.5'
-#       jupytext_version: 1.14.0
+#       format_name: percent
+#       format_version: '1.3'
+#       jupytext_version: 1.15.2
 #   kernelspec:
 #     display_name: Python 3 (ipykernel)
 #     language: python
 #     name: python3
 # ---
 
+# %%
 """
 displayfile is used to display certain types of files.
 The module lets us preview a file, open a file, and open its directory.
@@ -34,14 +36,11 @@ Example:
         display(d)
 
 """
-# %run _dev_sys_path_append.py
-# %run __init__.py
+# # %run _dev_maplocal_params.py
 # %load_ext lab_black
-
-# +
+# %%
 import pathlib
 import functools
-from wcmatch.pathlib import Path as wcPath
 from IPython.display import (
     display,
     clear_output,
@@ -51,7 +50,7 @@ import time
 import typing as ty
 import ipywidgets as w
 import traitlets as tr
-from pydantic import BaseModel, validator, HttpUrl
+from pydantic import ConfigDict, BaseModel, validator, HttpUrl
 
 #  local imports
 from ipyautoui.autodisplay_renderers import (
@@ -59,7 +58,7 @@ from ipyautoui.autodisplay_renderers import (
     handle_compound_ext,
 )
 from ipyautoui._utils import (
-    open_file,
+    open_path,
     make_new_path,
     frozenmap,
     get_ext,
@@ -75,7 +74,7 @@ from ipyautoui.constants import (
     KWARGS_COLLAPSE_ALL_FILES,
     KWARGS_HOME_DISPLAY_FILES,
 )
-
+from wcmatch import fnmatch
 import requests
 
 # from mf library
@@ -85,16 +84,17 @@ import requests
 #     pass
 
 
-# -
-
-
+# %%
 def merge_default_renderers(
-    renderers: dict[str, ty.Callable],
+    renderers: ty.Optional[dict[str, ty.Callable]],
     default_renderers: frozenmap[str, ty.Callable] = DEFAULT_FILE_RENDERERS,
 ) -> dict[str, ty.Callable]:
+    if renderers is None:
+        renderers = {}
     return {**dict(default_renderers), **renderers}
 
 
+# %%
 def get_renderers(
     renderers: ty.Optional[dict[str, ty.Callable]],
     extend_default_renderers: bool = True,
@@ -107,33 +107,36 @@ def get_renderers(
         return dict(DEFAULT_FILE_RENDERERS)
 
 
-# +
+from pydantic import field_validator, ValidationInfo, Field
+
+
+# %%
 class DisplayObjectActions(BaseModel):
     """base object with callables for creating a display object"""
 
     renderers: dict[str, ty.Callable] = dict(DEFAULT_FILE_RENDERERS)
-    path: ty.Union[str, pathlib.Path, HttpUrl, ty.Callable]
-    ext: str = None
-    name: str = None
-    check_exists: ty.Callable = None
-    renderer: ty.Callable = None
-    check_date_modified: ty.Callable = None
+    path: ty.Optional[ty.Union[str, pathlib.Path, HttpUrl, ty.Callable]]
+    ext: ty.Optional[str] = Field(None, validate_default=True)
+    name: ty.Optional[str] = Field(None, validate_default=True)
+    check_exists: ty.Optional[ty.Callable] = Field(None, validate_default=True)
+    renderer: ty.Optional[ty.Callable] = Field(None, validate_default=True)
+    check_date_modified: ty.Optional[ty.Callable] = Field(None, validate_default=True)
 
-    @validator("renderer", always=True)
-    def _renderer(cls, v, values):
+    @field_validator("renderer")
+    @classmethod
+    def _renderer(cls, v: ty.Callable, info: ValidationInfo):
         if v is None:
-            ext = values["ext"]
-            map_ = values["renderers"]
-            if ext in map_.keys():
-                fn = functools.partial(map_[ext], values["path"])
+            ext = info.data["ext"]
+            map_ = info.data["renderers"]
+            if ext is not None and ext in map_.keys():
+                fn = functools.partial(map_[ext], info.data["path"])
             else:
                 fn = lambda: w.HTML("File renderer not found")
             return fn
         else:
-            return functools.partial(v, values["path"])
+            return functools.partial(v, info.data["path"])
 
-    class Config:
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(arbitrary_types_allowed=True)
 
 
 def check_exists(path):
@@ -144,76 +147,91 @@ def check_exists(path):
 
 
 class DisplayFromPath(DisplayObjectActions):
-    newroot: pathlib.PureWindowsPath = pathlib.PureWindowsPath("J:/")
-    path_new: pathlib.Path = None
-    open_file: ty.Callable = None
-    open_folder: ty.Callable = None
+    path_new: ty.Optional[pathlib.Path] = None
+    open_file: ty.Optional[ty.Callable] = None
+    open_folder: ty.Optional[ty.Callable] = None
 
-    @validator("path", always=True)
-    def _path(cls, v, values):
-        return pathlib.Path(v)
+    @field_validator("path")
+    @classmethod
+    def _path(cls, v):
+        if v is not None:
+            return pathlib.Path(v)
+        else:
+            return v
 
-    @validator("path_new", always=True)
-    def _path_new(cls, v, values):
-        return make_new_path(values["path"], newroot=values["newroot"])
+    @field_validator("path_new")
+    @classmethod
+    def _path_new(cls, v, info: ValidationInfo):
+        p = info.data["path"]
+        if p is not None:
+            return make_new_path(p.absolute())
+        else:
+            return p
 
-    @validator("name", always=True)
-    def _name(cls, v, values):
-        if values["path"] is not None:
-            v = values["path"].name
+    @field_validator("name")
+    @classmethod
+    def _name(cls, v, info: ValidationInfo):
+        if info.data["path"] is not None:
+            v = info.data["path"].name
         return v
 
-    @validator("ext", always=True)
-    def _ext(cls, v, values):
-        if values["path"] is not None:
-            v = get_ext(values["path"])
-            v = handle_compound_ext(v, renderers=values["renderers"])
+    @field_validator("ext")
+    @classmethod
+    def _ext(cls, v, info: ValidationInfo):
+        p = info.data["path"]
+        rs = info.data["renderers"]
+        if p is not None:
+            v = get_ext(p)
+            v = handle_compound_ext(v, renderers=rs)
         if v is None:
             ValueError("ext must be given to map data to renderer")
         return v
 
-    @validator("check_exists", always=True)
-    def _check_exists(cls, v, values):
-        fn = functools.partial(check_exists, values["path"])
+    @field_validator("check_exists")
+    @classmethod
+    def _check_exists(cls, v, info: ValidationInfo):
+        p = info.data["path"]
+        fn = lambda: None
+        if p is not None:
+            fn = functools.partial(check_exists, p)
         return fn
 
-    @validator("check_date_modified", always=True)
-    def _date_modified(cls, v, values):
-        p = values["path"]
+    @field_validator("check_date_modified")
+    @classmethod
+    def _check_date_modified(cls, v, info: ValidationInfo):
+        p = info.data["path"]
         if p is not None:
             return functools.partial(st_mtime_string, p)
         else:
             return None
 
-    @validator("open_file", always=True)
-    def _open_file(cls, v, values):
-        p = values["path"]
+    @field_validator("open_file")
+    @classmethod
+    def _open_file(cls, v, info: ValidationInfo):
+        p = info.data["path"]
         if p is not None:
-            fn = functools.partial(open_file, p, newroot=values["newroot"])
-            return fn
+            return functools.partial(open_path, p)
         else:
-            return lambda: "Error: path given is None"
+            return None
 
-    @validator("open_folder", always=True)
-    def _open_folder(cls, v, values):
-        p = values["path"]
+    @field_validator("open_folder")
+    @classmethod
+    def _open_folder(cls, v, info: ValidationInfo):
+        p = info.data["path"]
         if not p.is_dir():
             p = p.parent
         if p is not None:
-            fn = functools.partial(open_file, p, newroot=values["newroot"])
+            fn = functools.partial(open_path, p)
             return fn
         else:
             return lambda: "Error: path given is None"
 
-    class Config:
-        arbitrary_types_allowed = True
+    model_config = ConfigDict(arbitrary_types_allowed=True)
 
 
 def url_ok(url):
-
     # exception block
     try:
-
         # pass the url into
         # request.head
         # response = requests.head(url)
@@ -234,14 +252,16 @@ def url_ok(url):
 class DisplayFromRequest(DisplayObjectActions):
     path: HttpUrl
 
-    @validator("check_exists", always=True)
-    def _check_exists(cls, v, values):
-        fn = functools.partial(url_ok, values["path"])
+    @field_validator("check_exists")
+    @classmethod
+    def _check_exists(cls, v, info: ValidationInfo):
+        fn = functools.partial(url_ok, info.data["path"])
         return fn
 
-    @validator("name", always=True)
-    def _name(cls, v, values):
-        return values["path"].path
+    @field_validator("name")
+    @classmethod
+    def _name(cls, v, info: ValidationInfo):
+        return info.data["path"].path
 
 
 def check_callable_in_namespace(fn: ty.Callable):  # NTO USED
@@ -261,25 +281,24 @@ def check_callable(fn: ty.Callable):  # NTO USED
 class DisplayFromCallable(DisplayObjectActions):
     path: ty.Callable
 
-    @validator("check_exists", always=True)
-    def _check_exists(cls, v, values):
-        return functools.partial(check_callable, values["path"])
+    @field_validator("check_exists")
+    @classmethod
+    def _check_exists(cls, v, info: ValidationInfo):
+        fn = functools.partial(check_callable, info.data["path"])
+        return fn
 
-    @validator("name", always=True)
-    def _name(cls, v, values):
-        if v is not None:
-            return v
-        else:
-            return values["path"].__name__
+    @field_validator("name")
+    @classmethod
+    def _name(cls, v, info: ValidationInfo):
+        return info.data["path"].__name__
 
 
-# -
-
+# %%
 if __name__ == "__main__":
     d = DisplayFromPath(path="__init__.py")
     display(d.renderer())
 
-# +
+# %%
 # TODO: separate out the bit that is display data and display from path...
 # TODO: probs useful to have a `value` trait (allowing the object to be updated instead of remade)
 #       this probably means having DisplayObject as a base class and extending it for display file...
@@ -347,7 +366,6 @@ class DisplayObject(w.VBox):
                 default is: ("exists", "openpreview", "openfile", "openfolder", "name")
                 reduce tuple to hide components
         """
-
         self._init_form()  # generic form only
         self._init_controls()
         super().__init__(display_actions=display_actions, **kwargs)
@@ -355,57 +373,13 @@ class DisplayObject(w.VBox):
         self.children = [self.bx_bar, self.bx_out]
 
     def _update_bx_bar(self, order):
-        self.bx_bar.children = [getattr(self, l) for l in order]
-
-    @classmethod
-    def from_path(
-        cls,
-        path,
-        newroot=pathlib.PureWindowsPath("J:/"),
-        renderers=None,
-        extend_default_renderers=True,
-        auto_open=False,
-    ):
-        renderers = get_renderers(
-            renderers=renderers, extend_default_renderers=extend_default_renderers
-        )
-        display_actions = DisplayFromPath(
-            path=path, newroot=newroot, renderers=renderers
-        )
-        return cls(display_actions=display_actions, auto_open=auto_open)
-
-    @classmethod
-    def from_request(
-        cls,
-        path,
-        ext,
-        renderers=None,
-        extend_default_renderers=True,
-        auto_open=False,
-    ):
-        renderers = get_renderers(
-            renderers=renderers, extend_default_renderers=extend_default_renderers
-        )
-        display_actions = DisplayFromRequest(path=path, ext=ext, renderers=renderers)
-        return cls(display_actions=display_actions, auto_open=auto_open)
-
-    @classmethod
-    def from_callable(
-        cls,
-        path,
-        ext,
-        renderers=None,
-        extend_default_renderers=True,
-        auto_open=False,
-    ):
-        renderers = get_renderers(
-            renderers=renderers, extend_default_renderers=extend_default_renderers
-        )
-        display_actions = DisplayFromCallable(path=path, ext=ext, renderers=renderers)
-        return cls(display_actions=display_actions, auto_open=auto_open)
-
-    def tooltip_openpath(self, path):
-        return str(make_new_path(path, newroot=self.display_actions.newroot))
+        li = []
+        for l in order:
+            try:
+                li.append(getattr(self, l))
+            except:
+                pass
+        self.bx_bar.children = li
 
     def _init_form(self):
         self.exists = w.Valid(
@@ -416,8 +390,6 @@ class DisplayObject(w.VBox):
             layout=w.Layout(width="20px", height=BUTTON_HEIGHT_MIN),
         )
         self.openpreview = w.ToggleButton(**KWARGS_OPENPREVIEW)
-        self.openfile = w.Button(**KWARGS_OPENFILE)
-        self.openfolder = w.Button(**KWARGS_OPENFOLDER)
         self.name = w.HTML(
             layout=w.Layout(justify_items="center"),
         )
@@ -426,26 +398,14 @@ class DisplayObject(w.VBox):
         self.out_caller.layout.display = "none"
         self.out.layout.display = "none"
         self.bx_bar = w.HBox()
-
         self.bx_out = w.VBox()
         self.bx_out.children = [self.out_caller, self.out]
 
     def _update_form(self):
-        if isinstance(self.display_actions.path, pathlib.PurePath):
-            self.openfile.tooltip = f"""
-open file:
-{self.tooltip_openpath(self.display_actions.path)}
-"""
-            self.openfolder.tooltip = f"""
-open folder:
-{self.tooltip_openpath(self.display_actions.path.parent)}
-"""
         self.name.value = "<b>{0}</b>".format(self.display_actions.name)
         self.check_exists()
 
     def _init_controls(self):
-        self.openfile.on_click(self._openfile)
-        self.openfolder.on_click(self._openfolder)
         self.openpreview.observe(self._openpreview, names="value")
 
     def check_exists(self):
@@ -477,6 +437,98 @@ open folder:
             with self.out:
                 clear_output()
 
+
+class DisplayCallable(DisplayObject):
+    def __init__(
+        self,
+        value,
+        ext,
+        renderers=None,
+        extend_default_renderers=True,
+        **kwargs,
+    ):
+        renderers = get_renderers(
+            renderers=renderers, extend_default_renderers=extend_default_renderers
+        )
+        display_actions = DisplayFromCallable(path=value, ext=ext, renderers=renderers)
+        super().__init__(display_actions=display_actions, **kwargs)
+
+
+class DisplayRequest(DisplayObject):
+    def __init__(
+        self,
+        value,
+        ext,
+        renderers=None,
+        extend_default_renderers=True,
+        **kwargs,
+    ):
+        renderers = get_renderers(
+            renderers=renderers, extend_default_renderers=extend_default_renderers
+        )
+        display_actions = DisplayFromRequest(path=path, ext=ext, renderers=renderers)
+        super().__init__(display_actions=display_actions, **kwargs)
+
+
+class DisplayPath(DisplayObject):
+    _value = tr.Unicode(default_value="")
+
+    @tr.default("order")
+    def _default_order(self):
+        return ORDER_DEFAULT
+
+    def __init__(
+        self,
+        value,
+        renderers=None,
+        extend_default_renderers=True,
+        **kwargs,
+    ):
+        self.renderers = get_renderers(
+            renderers=renderers, extend_default_renderers=extend_default_renderers
+        )
+        display_actions = DisplayFromPath(path=value, renderers=self.renderers)
+        self._update_form_DisplayPath()
+        super().__init__(display_actions=display_actions, **kwargs)
+        self._init_controls_DisplayPath()
+        self._update_path_tooltips()
+
+    def _update_form_DisplayPath(self):
+        self.openfile = w.Button(**KWARGS_OPENFILE)
+        self.openfolder = w.Button(**KWARGS_OPENFOLDER)
+
+    def _update_path_tooltips(self):
+        new_path = lambda path: str(make_new_path(path))
+        if isinstance(self.display_actions.path, pathlib.PurePath):
+            self.openfile.tooltip = f"""
+open file:
+{new_path(self.display_actions.path)}
+"""
+            self.openfolder.tooltip = f"""
+open folder:
+{new_path(self.display_actions.path.parent)}
+"""
+
+    def _init_controls_DisplayPath(self):
+        self.openfile.on_click(self._openfile)
+        self.openfolder.on_click(self._openfolder)
+
+    @property
+    def path(self):
+        return pathlib.Path(self.value)
+
+    @path.setter
+    def path(self, value):
+        self.value = str(value)
+
+    @property
+    def value(self):
+        return self._value
+
+    @value.setter
+    def value(self, value):
+        self.display_actions = DisplayFromPath(path=value, renderers=self.renderers)
+
     def _openfile(self, sender):
         self.out_caller.layout.display = ""
         with self.out_caller:
@@ -496,50 +548,24 @@ open folder:
         self.out_caller.layout.display = "none"
 
 
-class DisplayPath(DisplayObject):
-    _value = tr.Unicode(default_value="")
-
-    def __init__(
-        self,
-        value,
-        newroot=pathlib.PureWindowsPath("J:/"),
-        renderers=None,
-        extend_default_renderers=True,
-        **kwargs,
-    ):
-        self.newroot = newroot
-        self.renderers = get_renderers(
-            renderers=renderers, extend_default_renderers=extend_default_renderers
-        )
-        display_actions = DisplayFromPath(
-            path=value, newroot=self.newroot, renderers=self.renderers
-        )
-        super().__init__(display_actions=display_actions, **kwargs)
-
-    @property
-    def value(self):
-        return self._value
-
-    @value.setter
-    def value(self, value):
-        self._value = ""
-        self.display_actions = DisplayFromPath(
-            path=value, newroot=self.newroot, renderers=self.renderers
-        )
-
-
-# -
+# %%
 if __name__ == "__main__":
     d = DisplayFromPath(path="__init__.py")
     do = DisplayObject(d)
     display(do)
 
+# %%
+if __name__ == "__main__":
+    DisplayPath(value="__init__.py")
+
+# %%
 if __name__ == "__main__":
     path = "https://catfact.ninja/fact"
     ext = ".json"
     display(DisplayFromRequest(path=path, ext=ext).renderer())
 
 
+# %%
 if __name__ == "__main__":
     path = "https://catfact.ninja/fact"
     ext = ".json"
@@ -549,18 +575,20 @@ if __name__ == "__main__":
 
     display(DisplayFromCallable(path=get_catfact, ext=ext).renderer())
 
+# %%
 if __name__ == "__main__":
-
     path = "https://catfact.ninja/fact"
     ext = ".json"
-    display(DisplayObject.from_request(path=path, ext=ext))
+    display(DisplayRequest(value=path, ext=ext, order=ORDER_DEFAULT))
 
+# %%
 if __name__ == "__main__":
-
+    # FIXME:
     ext = ".json"
-    dobj = DisplayObject.from_callable(path=get_catfact, ext=ext)
+    dobj = DisplayCallable(value=get_catfact, ext=ext)
     display(dobj)
 
+# %%
 if __name__ == "__main__":
     import json
     from datetime import datetime
@@ -580,13 +608,12 @@ if __name__ == "__main__":
 
     path = "https://catfact.ninja/fact"
     ext = ".catfact"
-    d = DisplayObject.from_request(
-        path=path, ext=ext, renderers={".catfact": display_catfact}
-    )
+    d = DisplayRequest(value=path, ext=ext, renderers={".catfact": display_catfact})
     display(d)
 
+# %%
 if __name__ == "__main__":
-    from ipyautoui.test_schema import TestAutoLogic
+    from ipyautoui.demo_schemas import CoreIpywidgets
     from ipyautoui.autoui import AutoUi
     from ipyautoui.constants import load_test_constants
 
@@ -594,15 +621,12 @@ if __name__ == "__main__":
     DIR_FILETYPES = load_test_constants().DIR_FILETYPES
     paths = list(pathlib.Path(DIR_FILETYPES).glob("*"))
     path = paths[6]
-    d = DisplayObject.from_path(path)
+    d = DisplayPath(path)
     display(d)
     # ------------------
 
 
-if __name__ == "__main__":
-    d1 = DisplayPath(path)
-    display(d1)
-
+# %%
 if __name__ == "__main__":
     d.order = (
         "openpreview",
@@ -610,22 +634,28 @@ if __name__ == "__main__":
     )
     d.auto_open = True
 
+# %%
 if __name__ == "__main__":
-    from ipyautoui.test_schema import TestAutoLogic
+    from ipyautoui.demo_schemas import CoreIpywidgets
 
     user_file_renderers = AutoUi.create_autodisplay_map(
-        ext=".aui.json", schema=TestAutoLogic
+        ext=".aui.json", schema=CoreIpywidgets
     )
     path1 = tests_constants.PATH_TEST_AUI
 
-    d = DisplayObject.from_path(path1, renderers=user_file_renderers)
+    d = DisplayPath(path1, renderers=user_file_renderers)
+    d.order = ORDER_DEFAULT
     display(d)
 
-# +
-from wcmatch import fnmatch
-
 
+# %%
 class AutoDisplay(tr.HasTraits):
+    order = tr.Tuple(default_value=ORDER_NOTPATH, allow_none=False)
+
+    @tr.observe("order")
+    def _observe_order(self, change):
+        [d._update_bx_bar(change["new"]) for d in self.display_objects]
+
     """
     displays the contents of a file in the notebook.
     comes with the following default renderers:
@@ -654,13 +684,6 @@ class AutoDisplay(tr.HasTraits):
     if you want to display the data in a specific way.
     """
 
-    #     _paths = tr.List()
-
-    #     @validate("_paths")
-    #     def _valid_value(self, proposal):
-    #         """makes path a wcmatch.Path (for enhanced pattern matching) and filters out directories"""
-    #         return [wcPath(p) for p in proposal["value"] if not pathlib.Path(p).is_dir()]
-
     def __init__(
         self,
         display_objects_actions: ty.List[DisplayObjectActions],
@@ -683,7 +706,6 @@ class AutoDisplay(tr.HasTraits):
         self._init_controls()
         self.title = title
         self._display_objects_actions = display_objects_actions
-
         self.display_objects_actions = display_objects_actions
         self.display_showhide = display_showhide
         self.patterns = patterns
@@ -692,7 +714,6 @@ class AutoDisplay(tr.HasTraits):
     def from_paths(
         cls,
         paths: ty.List[pathlib.Path],
-        newroot=pathlib.PureWindowsPath("J:/"),  # TODO: maproots
         renderers=None,
         patterns: ty.Union[str, ty.List] = None,
         title: ty.Union[str, None] = None,
@@ -707,7 +728,6 @@ class AutoDisplay(tr.HasTraits):
 
         display_objects_actions = cls.actions_from_paths(
             paths=paths,
-            newroot=newroot,
             renderers=renderers,
         )
         return cls(
@@ -823,13 +843,9 @@ class AutoDisplay(tr.HasTraits):
     @staticmethod
     def actions_from_paths(
         paths: ty.List[pathlib.Path],
-        newroot=pathlib.PureWindowsPath("J:/"),  # maproots
         renderers=None,
     ):
-        return [
-            DisplayFromPath(path=path, newroot=newroot, renderers=renderers)
-            for path in paths
-        ]
+        return [DisplayFromPath(path=path, renderers=renderers) for path in paths]
 
     @staticmethod
     def actions_from_requests(map_requests: ty.Dict[str, HttpUrl], renderers=None):
@@ -850,7 +866,6 @@ class AutoDisplay(tr.HasTraits):
     def add_from_paths(
         self,
         paths,
-        newroot=pathlib.PureWindowsPath("J:/"),
         renderers=None,
     ):
         if renderers is not None:
@@ -858,9 +873,7 @@ class AutoDisplay(tr.HasTraits):
         else:
             renderers = DEFAULT_FILE_RENDERERS
         paths = [p for p in paths if p not in self.paths]
-        _new_actions = self.actions_from_paths(
-            paths=paths, newroot=newroot, renderers=renderers
-        )
+        _new_actions = self.actions_from_paths(paths=paths, renderers=renderers)
         actions = self.display_objects_actions + _new_actions
         self.display_objects_actions = actions
 
@@ -990,27 +1003,30 @@ class AutoDisplay(tr.HasTraits):
         [d._update_file() for d in self.display_objects]
 
 
-# +
+# %%
 # TODO: render pdf update the relative path
 
 if __name__ == "__main__":
-    from ipyautoui.test_schema import TestAutoLogic
+    from ipyautoui.demo_schemas import CoreIpywidgets
     from ipyautoui.autoui import AutoUi
     from ipyautoui.constants import load_test_constants
 
     tests_constants = load_test_constants()
     DIR_FILETYPES = load_test_constants().DIR_FILETYPES
     paths = list(pathlib.Path(DIR_FILETYPES).glob("*"))
-    ad = AutoDisplay.from_paths(
-        paths, newroot=pathlib.PureWindowsPath("C:/"), patterns="*.csv"
-    )
+    ad = AutoDisplay.from_paths(paths, patterns="*.csv")
     display(ad)
-# -
+# %%
 if __name__ == "__main__":
-    from ipyautoui.test_schema import TestAutoLogic
+    # FIXME
+    ad.order = ORDER_DEFAULT
+
+# %%
+if __name__ == "__main__":
+    from ipyautoui.demo_schemas import CoreIpywidgets
 
     user_file_renderers = AutoUi.create_autodisplay_map(
-        ext=".aui.json", schema=TestAutoLogic
+        ext=".aui.json", schema=CoreIpywidgets
     )
 
     test_ui = AutoDisplay.from_paths(
@@ -1021,8 +1037,9 @@ if __name__ == "__main__":
 
     display(test_ui)
 
+# %%
 if __name__ == "__main__":
-    from ipyautoui.test_schema import TestAutoLogic
+    from ipyautoui.demo_schemas import CoreIpywidgets
 
     test_ui = AutoDisplay.from_requests(
         map_requests={
@@ -1035,8 +1052,9 @@ if __name__ == "__main__":
 
     display(test_ui)
 
+# %% editable=true slideshow={"slide_type": ""}
 if __name__ == "__main__":
-    from ipyautoui.test_schema import TestAutoLogic
+    from ipyautoui.demo_schemas import CoreIpywidgets
     from pydantic import parse_obj_as
 
     test_ui = AutoDisplay.from_any(
@@ -1052,6 +1070,7 @@ if __name__ == "__main__":
 
     display(test_ui)
 
+# %%
 if __name__ == "__main__":
     import json
     from datetime import datetime
@@ -1078,4 +1097,4 @@ if __name__ == "__main__":
     display(Markdown("### From requests: "))
     display(test_display)
 
-
+# %%
