@@ -6,7 +6,7 @@
 #       extension: .py
 #       format_name: light
 #       format_version: '1.5'
-#       jupytext_version: 1.14.0
+#       jupytext_version: 1.15.2
 #   kernelspec:
 #     display_name: Python 3 (ipykernel)
 #     language: python
@@ -27,50 +27,29 @@ Example:
         from ipyautoui.constants import DISPLAY_AUTOUI_SCHEMA_EXAMPLE
         DISPLAY_AUTOUI_SCHEMA_EXAMPLE()
 """
-# %run _dev_sys_path_append.py
-# %run __init__.py
-#
+# %run _dev_maplocal_params.py
 # %load_ext lab_black
 
 import pathlib
 from IPython.display import display
-from pydantic import BaseModel
+from pydantic import BaseModel, ValidationError
 import json
 import traitlets as tr
-import traitlets_paths
 import typing as ty
-
+from ipyautoui.autoform import AutoObjectFormLayout
 from ipyautoui.custom import SaveButtonBar  # removing makes circular import error
-from ipyautoui.autoipywidget import AutoObject, get_from_schema_root
+import json
+import logging
+from ipyautoui.automapschema import map_widget, widgetcaller, _init_model_schema
+import ipywidgets as w
+from pydantic import BaseModel
+from ipyautoui.automapschema import pydantic_validate
+from IPython.display import clear_output
+
+logger = logging.getLogger(__name__)
+
 
 # +
-def rename_vjsf_schema_keys(obj, old="x_", new="x-"):
-    """recursive function to replace all keys beginning x_ --> x-
-    this allows schema Field keys to be definied in pydantic and then
-    converted to vjsf compliant schema"""
-
-    if type(obj) == list:
-        for l in list(obj):
-            if type(l) == str and l[0:2] == old:
-                l = new + l[2:]
-            if type(l) == list or type(l) == dict:
-                l = rename_vjsf_schema_keys(l)
-            else:
-                pass
-    if type(obj) == dict:
-        for k, v in obj.copy().items():
-            if k[0:2] == old:
-                obj[new + k[2:]] = v
-                del obj[k]
-            if type(v) == list or type(v) == dict:
-                v = rename_vjsf_schema_keys(v)
-            else:
-                pass
-    else:
-        pass
-    return obj
-
-
 def parse_json_file(path: pathlib.Path, model=None):
     """read json from file"""
     p = pathlib.Path(path)
@@ -101,15 +80,11 @@ class AutoUiFileMethods(tr.HasTraits):
     """AutoUiFileMethods is a mixin class that adds file methods to a AutoUi class
 
     Attributes:
-        path (traitlets_paths.Path): path to file
+        path (tr.Instance(klass=pathlib.PurePath)...): path to file
     """
 
-    path = traitlets_paths.Path(allow_none=True)
-
-    @tr.validate("path")
-    def _path(self, proposal):
-        if proposal["value"] is not None:
-            return pathlib.Path(proposal["value"])
+    path = tr.Instance(klass=pathlib.PurePath, default_value=None, allow_none=True)
+    fdir = tr.Instance(klass=pathlib.PurePath, default_value=None, allow_none=True)
 
     @tr.observe("path")
     def _observe_path(self, proposal):
@@ -177,67 +152,77 @@ class AutoUiFileMethods(tr.HasTraits):
             unsaved_changes = True
         self.load_value(parse_json_file(p, model=self.model), unsaved_changes)
 
+    def get_fdir(self, path=None, fdir=None):
+        if path is not None and fdir is None:
+            return pathlib.Path(path).parent
+        elif path is None and fdir is not None:
+            return fdir
+        elif path is not None and fdir is not None:
+            return fdir
+        else:
+            return None
+
+
+def get_from_schema_root(schema: ty.Dict, key: ty.AnyStr) -> ty.AnyStr:
+    return schema[key] if key in schema.keys() else ""
+
 
 class AutoRenderMethods:
     @classmethod
     def create_autoui_renderer(
-        cls,
-        schema: ty.Union[ty.Type[BaseModel], dict],
-        show_raw: bool = True,
-        path=None,
-        fns_onsave=None,
-        fns_onrevert=None,
+        cls, schema: ty.Union[ty.Type[BaseModel], dict], path=None, **kwargs
     ):
         if isinstance(schema, dict):
             docstring = f"AutoRenderer for {get_from_schema_root(schema, 'title')}"
         else:
-            docstring = (
-                f"AutoRenderer for {get_from_schema_root(schema.schema(), 'title')}"
-            )
+            docstring = f"AutoRenderer for {get_from_schema_root(schema.model_json_schema(), 'title')}"
 
         class AutoRenderer(cls):
             def __init__(self, path: pathlib.Path = path):
                 f"""{docstring}"""
                 if path is None:
                     raise ValueError("must give path")
-                super().__init__(
-                    schema,
-                    path=path,
-                    value=None,
-                    show_raw=show_raw,
-                    fns_onsave=fns_onsave,
-                    fns_onrevert=fns_onrevert,
-                )
+                super().__init__(schema, path=path, value=None, **kwargs)
 
         return AutoRenderer
 
     @classmethod
     def create_autodisplay_map(
-        cls,
-        schema: ty.Union[ty.Type[BaseModel], dict],
-        ext=".json",
-        show_raw: bool = True,
-        fns_onsave=None,
-        fns_onrevert=None,
+        cls, schema: ty.Union[ty.Type[BaseModel], dict], ext=".json", **kwargs
     ):
-        AutoRenderer = cls.create_autoui_renderer(
-            schema, show_raw=show_raw, fns_onsave=fns_onsave, fns_onrevert=fns_onrevert
-        )
+        AutoRenderer = cls.create_autoui_renderer(schema, **kwargs)
         return {ext: AutoRenderer}
 
 
 # +
-class AutoUi(AutoObject, AutoUiFileMethods, AutoRenderMethods):
+# TODO: should autoui be a function that returns the appropriate widget?
+#       this would solve the nested traits issue...
+class AutoUi(w.VBox, AutoObjectFormLayout, AutoUiFileMethods, AutoRenderMethods):
+
     """extends AutoObject and AutoUiCommonMethods to create an
     AutoUi user-input form. The data that can be saved to a json
     file `path` and loaded from a json file.
 
     Attributes:
-        # inherited from AutoFileMethods
-        # ------------------------------
-        path (traitlets_paths.Path): path to file
 
-        # inherited from AutoObject
+        # AutoFileMethods
+        # ------------------------------
+        path (tr.Instance(klass=pathlib.PurePath, ... ): path to file
+
+        # AutoObjectFormLayout
+        # -------------------------
+        title (str): form title
+        description (str): form description
+        show_description (bool, optional): show the description. Defaults to True.
+        show_title (bool, optional): show the title. Defaults to True.
+        show_savebuttonbar (bool, optional): show the savebuttonbar. Defaults to True.
+        show_raw (bool, optional): show the raw json. Defaults to False.
+        fn_onshowraw (callable): do not edit
+        fn_onhideraw (callable): do not edit
+        fns_onsave (callable): additional functions to be called on save
+        fns_onrevert (callable): additional functions to be called on revert
+
+        # AutoObject
         # -------------------------
         _value (dict): use `value` to set and get. the value of the form. this is a dict of the form {key: value}
         fdir (path, optional): fdir to work from. useful for widgets that link to files. Defaults to None.
@@ -251,24 +236,48 @@ class AutoUi(AutoObject, AutoUiFileMethods, AutoRenderMethods):
         disabled (bool, optional): disables all widgets. If widgets are disabled
             using schema kwargs this is remembered when re-enabled. Defaults to False.
 
-        # inherited from AutoObjectFormLayout
-        # ----------------------------------
-        show_raw (bool, optional): show the raw json. Defaults to False.
-        show_description (bool, optional): show the description. Defaults to True.
-        show_title (bool, optional): show the title. Defaults to True.
-        show_savebuttonbar (bool, optional): show the savebuttonbar. Defaults to True.
-
     """
+    error = tr.Unicode(default_value=None, allow_none=True)
+    schema = tr.Dict()
+    model = tr.Type(klass=BaseModel, default_value=None, allow_none=True)
+    _value = tr.Any()  # TODO: update trait type on schema change
+    
+    @tr.observe("error")
+    def _error(self, on_change):
+        if self.error is None:
+            with self.out_error:
+                clear_output()
+            self.out_error.layout.display = "None"
+            
+        else:
+            self.out_error.layout.display = ""
+            with self.out_error:
+                clear_output()
+                print(self.error)
+            
+    @property
+    def value(self):
+        return self._value
+
+    @value.setter
+    def value(self, value):
+        """this is for setting the value via the API"""
+        if value is not None:
+            self.autowidget.value = value
+
+    @tr.observe("schema")
+    def _schema(self, on_change):
+        self.caller = map_widget(self.schema)
+        self.autowidget = widgetcaller(self.caller)
+        self.children = [self.autowidget]
+
+    @property
+    def jsonschema_caller(self):
+        return summarize_di_callers(self)
 
     def __init__(
         self,
-        schema: ty.Union[ty.Type[BaseModel], dict],
-        value: dict = None,
-        path: pathlib.Path = None,  # TODO: generalise data retrieval?
-        update_map_widgets=None,
-        fns_onsave=None,
-        fns_onrevert=None,
-        # validate_onchange=True,  # TODO: sort out how the validation works
+        schema,
         **kwargs,
     ):
         """initialises the AutoUi. in Jupyter hit "cntrl + I" to load "inspector"
@@ -283,23 +292,71 @@ class AutoUi(AutoObject, AutoUiFileMethods, AutoRenderMethods):
             fns_onrevert (list, optional): list of functions to run on revert. Defaults to None.
             **kwargs: passed to AutoObject. see attributes for details.
         """
-
-        fdir = self.get_fdir(path=path, fdir=kwargs.get("fdir", None))
-        # init app
+        kwargs["model"], kwargs["schema"] = _init_model_schema(schema)
+        self.out_error = w.Output()
         super().__init__(
-            schema,
-            value=None,
-            update_map_widgets=update_map_widgets,
-            fdir=fdir,
-            fns_onsave=fns_onsave,
-            fns_onrevert=fns_onrevert,
             **kwargs,
         )
-        self.path = path
-        self.value = self._get_value(value, self.path)
+        # self.path = path
+        if "value" in kwargs:
+            self.value = self._get_value(kwargs["value"], self.path)
+            self.savebuttonbar.unsaved_changes = False
+        self.children = [
+            self.savebuttonbar,
+            self.hbx_title,
+            self.html_description,
+            self.out_error,
+            self.autowidget,
+            self.vbx_showraw,
+        ]
+        self._init_controls()
+        self._watch_change({"new": "bang!!!"})
+        {
+            setattr(self.autowidget, k, v)
+            for k, v in kwargs.items()
+            if k not in self.trait_names() and k in self.autowidget.trait_names()
+        }  # pass traits to autowidget on init.
+
+    def _init_controls(self):
+        self._init_watch_widget()
+
+    def _init_watch_widget(self):
+        v = self.autowidget
+        if v.has_trait("value"):
+            logger.debug(f"value trait found for: {v.value}")
+            v.observe(self._watch_change, "value")
+        elif v.has_trait("_value"):
+            logger.debug(f"_value trait found for: {v.value}")
+            v.observe(self._watch_change, "_value")
+        else:
+            pass
+
+    def _watch_change(self, on_change):
+        if on_change["new"] != self._value:
+            v = self.autowidget.value
+            if self.model is not None:
+                try:
+                    v_ = pydantic_validate(self.model, v)
+                    self.error = None
+                except ValidationError as e:
+                    self.error = str(e)
+                    v_ = v
+                if v_ != v:
+                    try:
+                        with self.autowidget.silence_autoui_traits():
+                            self.value = v_
+                    except:
+                        pass
+                else:
+                    self._value = v_
+            else:
+                self._value = v
+            if hasattr(self, "savebuttonbar"):
+                self.savebuttonbar.unsaved_changes = True
+            # NOTE: it is required to set the whole "_value" otherwise
+            #       traitlets doesn't register the change.
 
     def get_fdir(self, path=None, fdir=None):
-
         if path is not None and fdir is None:
             return pathlib.Path(path).parent
         elif path is None and fdir is not None:
@@ -309,77 +366,92 @@ class AutoUi(AutoObject, AutoUiFileMethods, AutoRenderMethods):
         else:
             return None
 
+    @property
+    def json(self):
+        return json.dumps(self.autowidget.value, indent=4)
+
+
+def summarize_di_callers(obj: AutoUi):  # NOTE: mainly used for demo
+    fn_ser = lambda k, v: str(v) if k == "autoui" else v
+    fn_item = lambda v: {
+        k_: fn_ser(k_, v_) for k_, v_ in v.model_dump().items() if k_ != "schema_"
+    }
+    if hasattr(obj.autowidget, "di_callers"):  # AutoObject
+        return {k: fn_item(v) for k, v in obj.autowidget.di_callers.items()}
+    else:  # root item
+        return fn_item(obj.caller)
+
+
+#     @classmethod
+#     def from_json_schema(cls, schema):
+#         schema = replace_refs(schema)
+
+#     def from_pydantic_model(cls, model):
+#         schema = replace_refs(model.model_json_schema())
+
 
 if __name__ == "__main__":
-    from ipyautoui.test_schema import TestAutoLogic, TestAutoLogicSimple
+    from ipyautoui.demo_schemas import CoreIpywidgets
 
+    fn = lambda: print("asdf")
+    fn.__name__ = "asdf"
     aui = AutoUi(
-        TestAutoLogicSimple,
-        path="test.json",
-        show_description=False,
-        show_raw=True,  
-        show_savebuttonbar=False,
+        CoreIpywidgets,
+        path=pathlib.Path("test.json"),
+        show_description=True,
+        show_raw=True,
+        show_savebuttonbar=True,
+        fns_onsave=[fn],
     )
     # aui.show_savebuttonbar = False
     display(aui)
 
-# +
-# aui.savebuttonbar.layout.display
-
-# + active=""
-# aui.save_actions.fns_onrevert[1]()
-
-# + active=""
-# aui.value = parse_json_file(aui._get_path(), model=aui.model)
-
-# + active=""
-# v = {'string': 'asdfasdfasdfasdf',
-#  'int_slider': 1,
-#  'int_text': 1,
-#  'int_range_slider': (0, 3),
-#  'float_slider': 2,
-#  'float_text': 2.2,
-#  'float_text_locked': 2.2,
-#  'float_range_slider': (0.0, 2.2),
-#  'checkbox': True,
-#  'dropdown': 'male',
-#  'dropdown_edge_case': 'female',
-#  'dropdown_simple': 'asd',
-#  'combobox': 'asd',
-#  'text': 'short text',
-#  'text_area': 'long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text long text ',
-#  'markdown': '\nSee details here: [__commonmark__](https://commonmark.org/help/)\n\nor press the question mark button. \n'}
-
-# +
-
-if __name__ == "__main__":
-    TestRenderer = AutoUi.create_autoui_renderer(TestAutoLogicSimple, path="test.json")
-    r = TestRenderer()
-    r.show_savebuttonbar = True
-    display(r)
-
-
-if __name__ == "__main__":
-    from ipyautoui.test_schema import TestAutoLogic, TestAutoLogicSimple
-
-    aui = AutoUi(
-        TestAutoLogicSimple,
-        path="test.json",
-        show_raw=True,
-        fn_onsave=lambda: print("test onsave"),
-    )
-    display(aui)
 # -
 
 if __name__ == "__main__":
-    aui.show_description = False
-    aui.show_title = False
-    aui.show_raw = False
+    from ipyautoui.demo_schemas import EditableGrid
+
+    fn = lambda: print("asdf")
+    fn.__name__ = "asdf"
+    aui = AutoUi(
+        EditableGrid,
+        path=pathlib.Path("test.json"),
+        show_description=True,
+        show_raw=True,
+        show_savebuttonbar=True,
+        fns_onsave=[fn],
+    )
+    # aui.show_savebuttonbar = False
+    display(aui)
 
-# + tags=[]
 if __name__ == "__main__":
-    # Renderer = AutoUi.create_autoui_renderer(schema)
-    from ipyautoui.autoipywidget import get_from_schema_root
+    from ipyautoui.demo_schemas import RootSimple
 
-    Renderer = AutoUi.create_autoui_renderer(TestAutoLogic, show_raw=False)
-    display(Renderer(path="test1.json"))
+    fn = lambda: print("asdf")
+    fn.__name__ = "asdf"
+    aui = AutoUi(
+        RootSimple,
+        path=pathlib.Path("test.json"),
+        show_description=True,
+        show_raw=True,
+        show_savebuttonbar=True,
+        fns_onsave=[fn],
+    )
+    # aui.show_savebuttonbar = False
+    display(aui)
+
+if __name__ == "__main__":
+    from ipyautoui.demo_schemas import RootArray
+
+    fn = lambda: print("asdf")
+    fn.__name__ = "asdf"
+    aui = AutoUi(
+        RootArray,
+        path=pathlib.Path("test.json"),
+        show_description=True,
+        show_raw=True,
+        show_savebuttonbar=True,
+        fns_onsave=[fn],
+    )
+    # aui.show_savebuttonbar = False
+    display(aui)
