@@ -19,6 +19,16 @@ ROW_WIDTH_MIN = "60px"
 BUTTON_MIN_SIZE = frozenmap(width=BUTTON_WIDTH_MIN, height=BUTTON_HEIGHT_MIN)
 # ---------------------------
 
+MAGIC_BUTTON_KWARGS = frozenmap(
+    {
+        "disabled": False,
+        "layout": {"width": "44px"},
+        "button_style": "warning",
+        "icon": "magic",
+        "style": {},
+        "tooltip": "add many",
+    }
+)
 TRUE_BUTTON_KWARGS = frozenmap(
     icon="check",
     style={"button_color": "lightgreen"},
@@ -28,6 +38,22 @@ TRUE_BUTTON_KWARGS = frozenmap(
     disabled=True,
 )
 
+FILEUPLD_BUTTON_KWARGS = frozenmap(
+    icon="upload",
+    description="",
+    button_style="info",
+    layout={"width": "60px"},
+    disabled=False,
+)
+
+IMAGE_BUTTON_KWARGS = frozenmap(
+    icon="image",
+    disabled=False,
+    button_style="info",
+    layout={"width": "44px"},
+    tooltip="images",
+)
+
 FALSE_BUTTON_KWARGS = frozenmap(
     icon="times",
     style={"button_color": "tomato"},
@@ -58,7 +84,7 @@ ADD_BUTTON_KWARGS = frozenmap(
     style={},
     button_style="success",
     tooltip="add item",
-    layout={"width": BUTTON_WIDTH_MIN}, #, "height": BUTTON_HEIGHT_MIN
+    layout={"width": BUTTON_WIDTH_MIN},  # , "height": BUTTON_HEIGHT_MIN
     disabled=False,
 )
 EDIT_BUTTON_KWARGS = frozenmap(
@@ -66,7 +92,7 @@ EDIT_BUTTON_KWARGS = frozenmap(
     style={},
     button_style="warning",
     tooltip="add item",
-    layout={"width": BUTTON_WIDTH_MIN}, #, "height": BUTTON_HEIGHT_MIN
+    layout={"width": BUTTON_WIDTH_MIN},  # , "height": BUTTON_HEIGHT_MIN
     disabled=False,
 )
 REMOVE_BUTTON_KWARGS = frozenmap(
@@ -74,7 +100,7 @@ REMOVE_BUTTON_KWARGS = frozenmap(
     style={},
     button_style="danger",
     tooltip="remove item",
-    layout={"width": BUTTON_WIDTH_MIN}, #, "height": BUTTON_HEIGHT_MIN
+    layout={"width": BUTTON_WIDTH_MIN},  # , "height": BUTTON_HEIGHT_MIN
     disabled=False,
 )
 COPY_BUTTON_KWARGS = frozenmap(
@@ -82,14 +108,14 @@ COPY_BUTTON_KWARGS = frozenmap(
     style={},
     button_style="primary",
     tooltip="copy item",
-    layout={"width": BUTTON_WIDTH_MIN}, #, "height": BUTTON_HEIGHT_MIN
+    layout={"width": BUTTON_WIDTH_MIN},  # , "height": BUTTON_HEIGHT_MIN
 )
 RELOAD_BUTTON_KWARGS = frozenmap(
     icon="sync",
     style={},
     button_style="info",
     tooltip="reload",
-    layout={"width": BUTTON_WIDTH_MIN}, #, "height": BUTTON_HEIGHT_MIN
+    layout={"width": BUTTON_WIDTH_MIN},  # , "height": BUTTON_HEIGHT_MIN
     disabled=False,
 )
 BLANK_BUTTON_KWARGS = frozenmap(
@@ -145,7 +171,7 @@ KWARGS_OPENFOLDER = frozenmap(
 KWARGS_DISPLAY = frozenmap(
     icon="plus",
     tooltip="display all files",
-    layout={"width": BUTTON_WIDTH_MIN, "height": BUTTON_HEIGHT_MIN},
+    layout={"width": BUTTON_WIDTH_MIN},  # , "height": BUTTON_HEIGHT_MIN
     disabled=False,
 )
 KWARGS_DISPLAY_ALL_FILES = frozenmap(
@@ -186,8 +212,8 @@ MAP_JSONSCHEMA_TO_IPYWIDGET = frozenmap(
         "minimum": "min",
         "maximum": "max",
         "enum": "options",
+        "examples": "options",
         "default": "value",
-        "description": "autoui_description",
     }
 )
 #  ^ this is how the json-schema names map to ipywidgets.
@@ -206,14 +232,3 @@ def load_test_constants():
         "constants", str(path_testing_constants)
     ).load_module()
     return test_constants
-
-
-def display_template_ui_model():
-    from ipyautoui import test_schema
-    from ipyautoui.autodisplay import PreviewPy
-
-    display(PreviewPy(test_schema, docstring_priority=False))
-
-
-def DISPLAY_AUTOUI_EXAMPLE():
-    display_template_ui_model()
