@@ -1,5 +1,6 @@
 from ipyautoui.custom.filechooser import FileChooser
 from ipyautoui.custom.multiselect_search import MultiSelectSearch
-from ipyautoui.custom.iterable import Array, Dictionary
+from ipyautoui.custom.iterable import AutoArray, Array, Dictionary
 from ipyautoui.custom.loadproject import LoadProject
 from ipyautoui.custom.buttonbars import SaveButtonBar
+from ipyautoui.custom.fileupload import FileUploadToDir, FilesUploadToDir
\ No newline at end of file
