@@ -8,18 +8,16 @@
 #       extension: .py
 #       format_name: light
 #       format_version: '1.5'
-#       jupytext_version: 1.14.0
+#       jupytext_version: 1.15.2
 #   kernelspec:
-#     display_name: Python 3.9 (XPython)
+#     display_name: Python 3 (ipykernel)
 #     language: python
-#     name: xpython
+#     name: python3
 # ---
 
 # +
 """General widget for editing data"""
-# %run _dev_sys_path_append.py
-# %run __init__.py
-# %run ../__init__.py
+# %run ../_dev_maplocal_params.py
 # %load_ext lab_black
 # TODO: move editgrid.py to root ?
 
@@ -29,15 +27,16 @@ import logging
 import traceback
 import pandas as pd
 import ipywidgets as w
-from IPython.display import clear_output
+from IPython.display import clear_output, display
 from markdown import markdown
 from pydantic import BaseModel, Field
 
-import ipyautoui.autoipywidget as aui
+from ipyautoui.autoobject import AutoObjectForm
 from ipyautoui.custom.buttonbars import CrudButtonBar
 from ipyautoui._utils import frozenmap
 from ipyautoui.constants import BUTTON_WIDTH_MIN
 from ipyautoui.custom.autogrid import AutoGrid
+from ipyautoui.custom.title_description import TitleDescription
 
 MAP_TRANSPOSED_SELECTION_MODE = frozenmap({True: "column", False: "row"})
 # TODO: rename "add" to "fn_add" so not ambiguous...
@@ -79,7 +78,7 @@ if __name__ == "__main__":
     def test_revert():
         print("Reverted.")
 
-    ui = aui.AutoObject(schema=TestModel)
+    ui = AutoObjectForm.from_pydantic_model(TestModel)
     display(ui)
 
 if __name__ == "__main__":
@@ -101,7 +100,7 @@ class RowEditor:
 # +
 class UiDelete(w.HBox):
     value = tr.Dict(default_value={})
-    columns = tr.List(allow_none=True, default_value=None)
+    columns = tr.List(default_value=[])
 
     @tr.observe("value")
     def observe_value(self, on_change):
@@ -109,15 +108,15 @@ class UiDelete(w.HBox):
 
     @tr.observe("columns")
     def observe_columns(self, on_change):
-        if self.columns is not None:
+        if self.columns:
             self.message_columns.value = f"columns shown: {str(self.columns)}"
         else:
-            self.message_columns.value = "---"
+            self.message_columns.value = ""
         self._update_display()
 
     @property
     def value_summary(self):
-        if self.columns is not None:
+        if self.columns:
             return {
                 k: {k_: v_ for k_, v_ in v.items() if k_ in self.columns}
                 for k, v in self.value.items()
@@ -135,16 +134,16 @@ class UiDelete(w.HBox):
         self.fn_delete = fn_delete
         self.out_delete = w.Output()
         self.bn_delete = w.Button(
-            icon="exclamation-triangle",
+            icon="trash",
             button_style="danger",
             layout=w.Layout(width=BUTTON_WIDTH_MIN),
         )
         self.vbx_messages = w.VBox()
         self.message = w.HTML(
-            "⚠️<b>Are you sure you want to delete?</b>⚠️ - <i>pressing the button will"
-            " permanently delete the selected data from the datagrid</i>"
+            "⚠️<b>Are you sure you want to delete?</b>⚠️ - <i>Pressing the button will"
+            " permanently delete the selected data</i>"
         )
-        self.message_columns = w.HTML(f"---")
+        self.message_columns = w.HTML(f"")
         self.vbx_messages.children = [
             self.message,
             self.message_columns,
@@ -231,32 +230,17 @@ class UiCopy(w.HBox):
 if __name__ == "__main__":
     display(UiCopy())
 
-
 # +
 # TODO: refactor how the datahandler works...
 # TODO: add a test for the datahandler...
 
 
-class EditGrid(w.VBox):
+# from ipyautoui.watch_validate import WatchValidate
+class EditGrid(w.VBox, TitleDescription):
     _value = tr.Tuple()  # using a tuple to guarantee no accidental mutation
     warn_on_delete = tr.Bool()
     show_copy_dialogue = tr.Bool()
     close_crud_dialogue_on_action = tr.Bool()
-    title = tr.Unicode(default_value=None, allow_none=True)
-    description = tr.Unicode(default_value=None, allow_none=True)
-    show_title = tr.Bool(default_value=True)
-
-    @tr.observe("title")
-    def observe_title(self, on_change):
-        self._update_title_description()
-
-    @tr.observe("description")
-    def observe_description(self, on_change):
-        self._update_title_description()
-
-    @tr.observe("show_title")
-    def observe_show_title(self, on_change):
-        self._update_title_description()
 
     @tr.observe("warn_on_delete")
     def observe_warn_on_delete(self, on_change):
@@ -278,10 +262,7 @@ class EditGrid(w.VBox):
 
     @value.setter
     def value(self, value):
-        if value == [] or value is None:
-            self.grid.data = self.grid.get_default_data()
-        else:
-            self.grid.data = self.grid._init_data(pd.DataFrame(value))
+        self.grid.data = self.grid._init_data(pd.DataFrame(value))
 
         # HOTFIX: Setting data creates bugs out transforms currently so reset transform applied
         _transforms = self.grid._transforms
@@ -299,19 +280,6 @@ class EditGrid(w.VBox):
     def _update_value_from_grid(self):
         self._value = self.grid.records()
 
-    def _update_title_description(self):
-        if not self.show_title:
-            self.html_title.layout.display = "None"
-        else:
-            if self.title is None and self.description is None:
-                self.html_title.layout.display = "None"
-            else:
-                self.html_title.layout.display = ""
-                get = lambda v: "" if v is None else v
-                self.html_title.value = (
-                    f"<b>{get(self.title)}</b>, <i>{get(self.description)}</i>"
-                )
-
     def __init__(
         self,
         schema: ty.Union[dict, ty.Type[BaseModel]],
@@ -330,8 +298,8 @@ class EditGrid(w.VBox):
         description: str = None,
         show_title: bool = True,
         **kwargs,
-    ):
-        self.html_title = w.HTML("")
+    ):  # TODO: use **kwargs to pass attributes to EditGrid as in AutoObject and AutoArray
+        self.html_title = w.HTML()
         self.description = description
         self.title = title
         self.show_title = show_title
@@ -339,10 +307,8 @@ class EditGrid(w.VBox):
         self.by_title = by_title
         self.by_alias = by_alias
         self.datahandler = datahandler
-        getvalue = (
-            lambda value: None
-            if value is None or value == [{}]
-            else pd.DataFrame(value)
+        getvalue = lambda value: (
+            None if value is None or value == [{}] else pd.DataFrame(value)
         )
         self.grid = AutoGrid(
             schema, data=getvalue(value), by_alias=self.by_alias, **kwargs
@@ -350,13 +316,13 @@ class EditGrid(w.VBox):
 
         self._init_form()
         if ui_add is None:
-            self.ui_add = aui.AutoObject(self.row_schema, app=self)
+            self.ui_add = AutoObjectForm.from_jsonschema(self.row_schema)
         else:
-            self.ui_add = ui_add(self.row_schema, app=self)
+            self.ui_add = ui_add.from_jsonschema(self.row_schema)
         if ui_edit is None:
-            self.ui_edit = aui.AutoObject(self.row_schema, app=self)
+            self.ui_edit = AutoObjectForm.from_jsonschema(self.row_schema)
         else:
-            self.ui_edit = ui_edit(self.row_schema, app=self)
+            self.ui_edit = ui_edit.from_jsonschema(self.row_schema)
         if ui_delete is None:
             self.ui_delete = UiDelete()
         else:
@@ -410,8 +376,8 @@ class EditGrid(w.VBox):
 
     def _init_form(self):
         super().__init__()
-        get_reload = (
-            lambda: None if self.datahandler is None else self._reload_datahandler
+        get_reload = lambda: (
+            None if self.datahandler is None else self._reload_datahandler
         )
         self.buttonbar_grid = CrudButtonBar(
             fn_add=self._add,
@@ -439,10 +405,11 @@ class EditGrid(w.VBox):
             self.ui_edit.order = self.grid.order
 
     def _observe_selections(self, onchange):
-        if self.buttonbar_grid.edit.value:
-            self._set_ui_edit_to_selected_row()
-        if self.buttonbar_grid.delete.value:
-            self._set_ui_delete_to_selected_row()
+        if self.grid.selections != []:
+            if self.buttonbar_grid.edit.value:
+                self._set_ui_edit_to_selected_row()
+            if self.buttonbar_grid.delete.value:
+                self._set_ui_delete_to_selected_row()
 
     # @debounce(0.1)  # TODO: make debounce work if too slow...
     def _grid_changed(self, onchange):
@@ -473,15 +440,21 @@ class EditGrid(w.VBox):
         self._check_one_row_selected()
 
     def _save_edit_to_grid(self):
+        selections = self.grid.selections  # Store current selection
+        selected_index = self.grid.selected_index
+        self.grid.selections = []
+        # ^ HOTFIX: Have to set empty to reselect later on
+
         if self.datahandler is not None:
             self._reload_all_data()
         else:
-            changes = self.grid.set_item_value(
-                self.grid.selected_index, self.ui_edit.value
-            )
+            self.grid.set_item_value(selected_index, self.ui_edit.value)
 
         if self.close_crud_dialogue_on_action:
             self.buttonbar_grid.edit.value = False
+        else:
+            # Reselect previous selection after reload.
+            self.grid.selections = selections
 
     def _set_ui_edit_to_selected_row(self):
         self.ui_edit.value = self.grid.selected
@@ -640,6 +613,8 @@ class EditGrid(w.VBox):
 # -
 
 if __name__ == "__main__":
+    from pydantic import RootModel
+
     # Test: EditGrid instance with multi-indexing.
     AUTO_GRID_DEFAULT_VALUE = [
         {
@@ -651,23 +626,26 @@ if __name__ == "__main__":
     AUTO_GRID_DEFAULT_VALUE = AUTO_GRID_DEFAULT_VALUE * 4
 
     class DataFrameCols(BaseModel):
-        string: str = Field("string", column_width=100, section="a")
-        integer: int = Field(1, column_width=80, section="a")
+        string: str = Field(
+            "string", json_schema_extra=dict(column_width=400, section="a")
+        )
+        integer: int = Field(1, json_schema_extra=dict(column_width=80, section="a"))
         floater: float = Field(
-            None, column_width=70, global_decimal_places=3, section="b"
+            None, json_schema_extra=dict(column_width=70, section="b")
         )
 
-    class TestDataFrame(BaseModel):
+    class TestDataFrame(RootModel):
         """a description of TestDataFrame"""
 
-        __root__: ty.List[DataFrameCols] = Field(
+        root: ty.List[DataFrameCols] = Field(
             default=AUTO_GRID_DEFAULT_VALUE,
-            format="dataframe",
-            datagrid_index_name=("section", "title"),
+            json_schema_extra=dict(
+                format="dataframe", datagrid_index_name=("section", "title")
+            ),
         )
 
     title = "The Wonderful Edit Grid Application"
-    description = markdown("Useful for all editing purposes" " whatever they may be 👍")
+    description = markdown("Useful for all editing purposes whatever they may be 👍")
     editgrid = EditGrid(
         schema=TestDataFrame,
         title=title,
@@ -677,6 +655,8 @@ if __name__ == "__main__":
         warn_on_delete=True,
         show_copy_dialogue=False,
         close_crud_dialogue_on_action=False,
+        global_decimal_places=1,
+        column_width={"String": 400},
     )
     editgrid.observe(lambda c: print("_value changed"), "_value")
     display(editgrid)
@@ -688,16 +668,30 @@ if __name__ == "__main__":
 
 
 if __name__ == "__main__":
+    # list column
+    class TestListCol(BaseModel):
+        li_col: list[str] = ["a"]
+        stringy: str = "as"
+        num: int = 1
+
+    class Test(RootModel):
+        root: list[TestListCol]
+
+    gr = EditGrid(Test, value=[{"li_col": ["a", "b"], "stringy": "string", "num": 23}])
+    display(gr)
+
+if __name__ == "__main__":
+    import random
 
     datahandler = DataHandler(
-        fn_get_all_data=lambda: AUTO_GRID_DEFAULT_VALUE * random.randint(1, 10),
+        fn_get_all_data=lambda: AUTO_GRID_DEFAULT_VALUE * random.randint(1, 5),
         fn_post=lambda v: print(v),
-        fn_patch=lambda v: print(v),
+        fn_patch=lambda v: v,
         fn_delete=lambda v: print(v),
         fn_copy=lambda v: print(v),
     )
     title = "The Wonderful Edit Grid Application"
-    description = markdown("Useful for all editing purposes" " whatever they may be 👍")
+    description = markdown("Useful for all editing purposes whatever they may be 👍")
     editgrid = EditGrid(
         schema=TestDataFrame,
         title=title,
@@ -711,29 +705,29 @@ if __name__ == "__main__":
 # -
 
 if __name__ == "__main__":
-    from ipyautoui.demo_schemas import CoreIpywidgets
-    from ipyautoui.autoipywidget import AutoObject
 
-    #     class TestDataFrame(BaseModel):
-    #         """a description of TestDataFrame"""
+    class DataFrameCols(BaseModel):
+        string: str = Field(
+            "string", json_schema_extra=dict(column_width=400, section="a")
+        )
+        integer: int = Field(1, json_schema_extra=dict(column_width=80, section="b"))
+        floater: float = Field(
+            None, json_schema_extra=dict(column_width=70, section="b")
+        )
 
-    #         __root__: ty.List[CoreIpywidgets] = Field(
-    #             [CoreIpywidgets().dict()], format="dataframe"
-    #         )
-    # TODO: ^ fix this
-
-    class TestDataFrame(BaseModel):
+    class TestDataFrame(RootModel):
         """a description of TestDataFrame"""
 
-        __root__: ty.List[DataFrameCols] = Field(
+        root: ty.List[DataFrameCols] = Field(
             [
                 DataFrameCols(
                     string="String",
                     integer=1,
                     floater=2.5,
-                ).dict()
+                ).model_dump()
             ],
-            format="dataframe",
+            json_schema_extra=dict(format="dataframe"),
+            # datagrid_index_name=("section", "title"),
         )
 
     description = markdown(
@@ -746,28 +740,12 @@ if __name__ == "__main__":
         ui_add=None,
         ui_edit=None,
         warn_on_delete=True,
+        by_title=False,
     )
     editgrid.observe(lambda c: print("_value changed"), "_value")
     display(editgrid)
 
 if __name__ == "__main__":
-    editgrid.transposed = True
-
-if __name__ == "__main__":
-
-    class TestDataFrame(BaseModel):
-        __root__: ty.List[DataFrameCols] = Field(
-            default=AUTO_GRID_DEFAULT_VALUE, format="dataframe"
-        )
+    editgrid.transposed = False
 
 
-if __name__ == "__main__":
-    from ipyautoui import AutoUi
-    from ipyautoui.autoipywidget import AutoObject
-
-    ui = AutoObject(schema=TestDataFrame)
-    ui.align_horizontal = True
-    ui.auto_open = True
-    ui.observe(lambda c: print("_value change"), "_value")
-    ui.di_widgets["__root__"].observe(lambda c: print("grid _value change"), "_value")
-    display(ui)
