@@ -45,13 +45,13 @@ class MultiSelectSearch(w.VBox):
     def __init__(self, options=[], value=[]):
         super().__init__()
         self.check_all = w.Button(
-            icon="fa-check-square-o",
+            icon="check-square-o",
             tooltip="Check all",
             button_style="success",
             layout=w.Layout(width=BUTTON_WIDTH_MIN),
         )
         self.uncheck_all = w.Button(
-            icon="fa-square-o",
+            icon="square-o",
             tooltip="Uncheck all",
             button_style="warning",
             layout=w.Layout(width=BUTTON_WIDTH_MIN),
@@ -88,7 +88,7 @@ class MultiSelectSearch(w.VBox):
         self.children = [self.ui]
 
     @property
-    def value(self):
+    def value(self):  # FIXME: don't set value on retrieval in case it was changed
         self._value = [
             name
             for name, checkbox in self.options_dict.items()
@@ -172,6 +172,8 @@ class MultiSelectSearch(w.VBox):
 
 
 if __name__ == "__main__":
+    from IPython.display import display
+    
     words = """
 a
 AAA
