@@ -15,8 +15,7 @@
 
 # +
 """simple set-up of outputting logging messages to widgets output."""
-# %run _dev_sys_path_append.py
-# %run __init__.py
+# %run ../_dev_maplocal_params.py
 #
 # %run ../__init__.py
 # %load_ext lab_black
@@ -174,6 +173,7 @@ class LoggingAccordion(w.Accordion):  # TODO; inherit from LoggingUiBase
 # -
 
 if __name__ == "__main__":
+    from IPython.display import display
 
     def div(a, b):
         try:
