@@ -1,5 +1,4 @@
 import traitlets as tr
-from traitlets_paths import PurePath
 import typing as ty
 import ipywidgets as w
 import inspect
@@ -10,7 +9,7 @@ import pathlib
 
 from ipyautoui import demo_schemas as demo_schemas
 from ipyautoui.demo_schemas import CoreIpywidgets
-from ipyautoui._utils import display_python_file
+from ipyautoui._utils import display_python_file, display_python_string
 from ipyautoui import AutoUi
 
 # TODO: add AutoRenderer functionality to demo
@@ -28,15 +27,23 @@ def get_order():
     li = [l.split("import ")[1] for l in li]
     return li
 
+pycall = """# copy the code below into your notebook to try the demo
+
+from ipyautoui import AutoUi
+from ipyautoui.demo_schemas import {name}
+ui = AutoUi({name})
+ui
+"""
+
 
 class Demo(w.Tab, tr.HasTraits):
     pydantic_model = tr.Type(klass=BaseModel)
-    python_file: PurePath()
+    python_file = tr.Instance(klass=pathlib.PurePath)
 
     @tr.observe("pydantic_model")
     def _observe_pydantic_model(self, change):
         try:
-            self.python_file = inspect.getfile(self.pydantic_model)
+            self.python_file = pathlib.Path(inspect.getfile(self.pydantic_model))
         except:
             raise ValueError(
                 "for the Demo to work, the `pydantic_model` must"
@@ -75,6 +82,8 @@ class Demo(w.Tab, tr.HasTraits):
             self.vbx_value,
         ]
         [self.set_title(k, v) for k, v in titles.items()]
+        self.out_pycall = w.Output()
+        self.vbx_pycall = w.VBox([self.out_pycall])
         self.out_pydantic = w.Output()
         self.vbx_pydantic.children = [self.out_pydantic]
 
@@ -88,9 +97,15 @@ class Demo(w.Tab, tr.HasTraits):
         self.vbx_value.children = [self.out_value]
         self.pydantic_model = pydantic_model
 
+    def _update_pycall(self):
+        with self.out_pycall:
+            clear_output()
+            display_python_string(pycall.format(name=self.pydantic_model.__name__))
+
     def _update_autoui(self):
         self.autoui = AutoUi(self.pydantic_model)
-        self.vbx_autoui.children = [self.autoui]
+        self._update_pycall()
+        self.vbx_autoui.children = [self.vbx_pycall, self.autoui ]
 
     def _update_pydantic(self):
         with self.out_pydantic:
@@ -100,22 +115,30 @@ class Demo(w.Tab, tr.HasTraits):
     def _update_jsonschema(self):
         s_sch = f"""
 ```json
-{json.dumps(self.pydantic_model.schema(), indent=4)}
+{json.dumps(self.pydantic_model.model_json_schema(), indent=4)}
 ```
 """
         with self.out_sch:
             clear_output()
             display(Markdown(s_sch))
+            
 
     def _update_jsonschema_caller(self):
-        s_sch = f"""
+        try:
+            s_sch = f"""
 ```json
-{json.dumps(self.autoui.schema, indent=4)}
+{json.dumps(self.autoui.jsonschema_caller, indent=4)}
 ```
 """
-        with self.out_caller:
-            clear_output()
-            display(Markdown(s_sch))
+            with self.out_caller:
+                clear_output()
+                display(Markdown(s_sch))
+        except:
+            with self.out_caller:
+                s_sch = self.autoui.jsonschema_caller
+                from pprint import pprint
+                clear_output()
+                display(pprint(s_sch))
 
     def _update_value(self):
         s_value = f"""
